@@ -36,12 +36,15 @@
 #' Approximate leave-future-out cross-validation for Bayesian time series
 #' models, Journal of Statistical Computation and Simulation, 90:14, 2499-2523.
 #' @examples
+#' data.table::setDTthreads(1) # For CRAN
 #' \donttest{
 #' # Please update your rstan and StanHeaders installation before running
 #' # on Windows
 #' if (!identical(.Platform$OS.type, "windows")) {
 #'   # this gives warnings due to the small number of iterations
-#'   out <- suppressWarnings(lfo(gaussian_example_fit, L = 20))
+#'   out <- suppressWarnings(
+#'     lfo(gaussian_example_fit, L = 20, chains = 1, cores = 1)
+#'   )
 #'   out$ELPD
 #'   out$ELPD_SE
 #' }
@@ -120,7 +123,7 @@ lfo <- function(x, L, verbose = TRUE, k_threshold = 0.7, ...) {
   #)
   elpds <- vector("list", T_ - L)
   subset_index_ <- lls[[time_var]] == timepoints[L + 1L]
-  elpds[[1L]] <- lls[
+  elpds[[1L]] <- stats::na.omit(lls[
     subset_index_
     # time == timepoints[L + 1L], ,
     # env = list(time = time, timepoints = timepoints, L = L)
@@ -129,7 +132,7 @@ lfo <- function(x, L, verbose = TRUE, k_threshold = 0.7, ...) {
     by = c(time_var, group_var)
     # by = list(time, id)#,
     # env = list(log_mean_exp = "log_mean_exp", time = time, id = id)
-  ][["elpd"]]
+  ][["elpd"]])
   i_refit <- L
   refits <- timepoints[L]
   ks <- vector("list", T_ - L - 1L)
@@ -211,7 +214,7 @@ lfo <- function(x, L, verbose = TRUE, k_threshold = 0.7, ...) {
           .SDcols = !patterns("_loglik$")
         ]
         elpds_subset_index_ <- lls[[time_var]] == timepoints[i + 1L]
-        elpds[[i - L + 1L]] <- lls[
+        elpds[[i - L + 1L]] <- stats::na.omit(lls[
           elpds_subset_index_ # ,
           # env = list(time = time, timepoints = timepoints, i = i)
         ][,
@@ -219,7 +222,7 @@ lfo <- function(x, L, verbose = TRUE, k_threshold = 0.7, ...) {
           # by = list(time, id)#,
           by = c(time_var, group_var)
           # env = list(log_mean_exp = "log_mean_exp", time = time, id = id)
-        ][["elpd"]]
+        ][["elpd"]])
       } else {
         lw <- loo::weights.importance_sampling(psis_obj, normalize = TRUE)
         elpds[[i - L + 1L]] <-
@@ -257,6 +260,7 @@ lfo <- function(x, L, verbose = TRUE, k_threshold = 0.7, ...) {
 #' @return Returns `x` invisibly.
 #' @export
 #' @examples
+#' data.table::setDTthreads(1) # For CRAN
 #' \donttest{
 #' # Please update your rstan and StanHeaders installation before running
 #' # on Windows
@@ -289,12 +293,15 @@ print.lfo <- function(x, ...) {
 #' @return A ggplot object.
 #' @export
 #' @examples
+#' data.table::setDTthreads(1) # For CRAN
 #' \donttest{
 #' # Please update your rstan and StanHeaders installation before running
 #' # on Windows
 #' if (!identical(.Platform$OS.type, "windows")) {
 #'   # This gives warnings due to the small number of iterations
-#'   plot(suppressWarnings(lfo(gaussian_example_fit, L = 20)))
+#'   plot(suppressWarnings(
+#'     lfo(gaussian_example_fit, L = 20, chains = 1, cores = 1)
+#'   ))
 #' }
 #' }
 #'
