@@ -271,8 +271,8 @@ fill_time_predict <- function(data, group_var, time_var, time_scale) {
     all(!time_duplicated),
     c(
       "Each time index must correspond to a single observation per group:",
-      `x` = "{cli::qty(d)}Group{?s} {.var {d}} of {.var {group_var}}
-             {cli::qty(d)}{?has/have} duplicate observations."
+      `x` = "{cli::qty(length(d))}Group{?s} {.var {d}} of {.var {group_var}}
+             {cli::qty(length(d))}{?has/have} duplicate observations."
     )
   )
   if (length(time) > 1L) {
